@@ -410,3 +410,131 @@ class SearchAllIamPoliciesAsyncPager:
 
     def __repr__(self) -> str:
         return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
+
+
+class ListSavedQueriesPager:
+    """A pager for iterating through ``list_saved_queries`` requests.
+
+    This class thinly wraps an initial
+    :class:`google.cloud.asset_v1.types.ListSavedQueriesResponse` object, and
+    provides an ``__iter__`` method to iterate through its
+    ``saved_queries`` field.
+
+    If there are more pages, the ``__iter__`` method will make additional
+    ``ListSavedQueries`` requests and continue to iterate
+    through the ``saved_queries`` field on the
+    corresponding responses.
+
+    All the usual :class:`google.cloud.asset_v1.types.ListSavedQueriesResponse`
+    attributes are available on the pager. If multiple requests are made, only
+    the most recent response is retained, and thus used for attribute lookup.
+    """
+
+    def __init__(
+        self,
+        method: Callable[..., asset_service.ListSavedQueriesResponse],
+        request: asset_service.ListSavedQueriesRequest,
+        response: asset_service.ListSavedQueriesResponse,
+        *,
+        metadata: Sequence[Tuple[str, str]] = ()
+    ):
+        """Instantiate the pager.
+
+        Args:
+            method (Callable): The method that was originally called, and
+                which instantiated this pager.
+            request (google.cloud.asset_v1.types.ListSavedQueriesRequest):
+                The initial request object.
+            response (google.cloud.asset_v1.types.ListSavedQueriesResponse):
+                The initial response object.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        self._method = method
+        self._request = asset_service.ListSavedQueriesRequest(request)
+        self._response = response
+        self._metadata = metadata
+
+    def __getattr__(self, name: str) -> Any:
+        return getattr(self._response, name)
+
+    @property
+    def pages(self) -> Iterator[asset_service.ListSavedQueriesResponse]:
+        yield self._response
+        while self._response.next_page_token:
+            self._request.page_token = self._response.next_page_token
+            self._response = self._method(self._request, metadata=self._metadata)
+            yield self._response
+
+    def __iter__(self) -> Iterator[asset_service.SavedQuery]:
+        for page in self.pages:
+            yield from page.saved_queries
+
+    def __repr__(self) -> str:
+        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
+
+
+class ListSavedQueriesAsyncPager:
+    """A pager for iterating through ``list_saved_queries`` requests.
+
+    This class thinly wraps an initial
+    :class:`google.cloud.asset_v1.types.ListSavedQueriesResponse` object, and
+    provides an ``__aiter__`` method to iterate through its
+    ``saved_queries`` field.
+
+    If there are more pages, the ``__aiter__`` method will make additional
+    ``ListSavedQueries`` requests and continue to iterate
+    through the ``saved_queries`` field on the
+    corresponding responses.
+
+    All the usual :class:`google.cloud.asset_v1.types.ListSavedQueriesResponse`
+    attributes are available on the pager. If multiple requests are made, only
+    the most recent response is retained, and thus used for attribute lookup.
+    """
+
+    def __init__(
+        self,
+        method: Callable[..., Awaitable[asset_service.ListSavedQueriesResponse]],
+        request: asset_service.ListSavedQueriesRequest,
+        response: asset_service.ListSavedQueriesResponse,
+        *,
+        metadata: Sequence[Tuple[str, str]] = ()
+    ):
+        """Instantiates the pager.
+
+        Args:
+            method (Callable): The method that was originally called, and
+                which instantiated this pager.
+            request (google.cloud.asset_v1.types.ListSavedQueriesRequest):
+                The initial request object.
+            response (google.cloud.asset_v1.types.ListSavedQueriesResponse):
+                The initial response object.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        self._method = method
+        self._request = asset_service.ListSavedQueriesRequest(request)
+        self._response = response
+        self._metadata = metadata
+
+    def __getattr__(self, name: str) -> Any:
+        return getattr(self._response, name)
+
+    @property
+    async def pages(self) -> AsyncIterator[asset_service.ListSavedQueriesResponse]:
+        yield self._response
+        while self._response.next_page_token:
+            self._request.page_token = self._response.next_page_token
+            self._response = await self._method(self._request, metadata=self._metadata)
+            yield self._response
+
+    def __aiter__(self) -> AsyncIterator[asset_service.SavedQuery]:
+        async def async_generator():
+            async for page in self.pages:
+                for response in page.saved_queries:
+                    yield response
+
+        return async_generator()
+
+    def __repr__(self) -> str:
+        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
