@@ -224,8 +224,7 @@ class AssetServiceGrpcTransport(AssetServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -302,5 +301,9 @@ class AssetServiceGrpcTransport(AssetServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("AssetServiceGrpcTransport",)
