@@ -82,19 +82,25 @@ def test__get_default_mtls_endpoint():
     assert AssetServiceClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-@pytest.mark.parametrize("client_class", [AssetServiceClient, AssetServiceAsyncClient,])
-def test_asset_service_client_from_service_account_info(client_class):
+@pytest.mark.parametrize(
+    "client_class,transport_name",
+    [
+        (AssetServiceClient, "grpc"),
+        (AssetServiceAsyncClient, "grpc_asyncio"),
+    ],
+)
+def test_asset_service_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "cloudasset.googleapis.com:443"
+        assert client.transport._host == ("cloudasset.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -122,22 +128,32 @@ def test_asset_service_client_service_account_always_use_jwt(
         use_jwt.assert_not_called()
 
 
-@pytest.mark.parametrize("client_class", [AssetServiceClient, AssetServiceAsyncClient,])
-def test_asset_service_client_from_service_account_file(client_class):
+@pytest.mark.parametrize(
+    "client_class,transport_name",
+    [
+        (AssetServiceClient, "grpc"),
+        (AssetServiceAsyncClient, "grpc_asyncio"),
+    ],
+)
+def test_asset_service_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "cloudasset.googleapis.com:443"
+        assert client.transport._host == ("cloudasset.googleapis.com:443")
 
 
 def test_asset_service_client_get_transport_class():
@@ -477,7 +493,9 @@ def test_asset_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -616,11 +634,16 @@ def test_asset_service_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [asset_service.SearchAllResourcesRequest, dict,]
+    "request_type",
+    [
+        asset_service.SearchAllResourcesRequest,
+        dict,
+    ],
 )
 def test_search_all_resources(request_type, transport: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -651,7 +674,8 @@ def test_search_all_resources_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -670,7 +694,8 @@ async def test_search_all_resources_async(
     request_type=asset_service.SearchAllResourcesRequest,
 ):
     client = AssetServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -705,13 +730,15 @@ async def test_search_all_resources_async_from_dict():
 
 
 def test_search_all_resources_field_headers():
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = asset_service.SearchAllResourcesRequest()
 
-    request.scope = "scope/value"
+    request.scope = "scope_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -727,18 +754,23 @@ def test_search_all_resources_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "scope=scope/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "scope=scope_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
 async def test_search_all_resources_field_headers_async():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = asset_service.SearchAllResourcesRequest()
 
-    request.scope = "scope/value"
+    request.scope = "scope_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -756,11 +788,16 @@ async def test_search_all_resources_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "scope=scope/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "scope=scope_value",
+    ) in kw["metadata"]
 
 
 def test_search_all_resources_flattened():
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -771,7 +808,9 @@ def test_search_all_resources_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.search_all_resources(
-            scope="scope_value", query="query_value", asset_types=["asset_types_value"],
+            scope="scope_value",
+            query="query_value",
+            asset_types=["asset_types_value"],
         )
 
         # Establish that the underlying call was made with the expected
@@ -790,7 +829,9 @@ def test_search_all_resources_flattened():
 
 
 def test_search_all_resources_flattened_error():
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -805,7 +846,9 @@ def test_search_all_resources_flattened_error():
 
 @pytest.mark.asyncio
 async def test_search_all_resources_flattened_async():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -820,7 +863,9 @@ async def test_search_all_resources_flattened_async():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         response = await client.search_all_resources(
-            scope="scope_value", query="query_value", asset_types=["asset_types_value"],
+            scope="scope_value",
+            query="query_value",
+            asset_types=["asset_types_value"],
         )
 
         # Establish that the underlying call was made with the expected
@@ -840,7 +885,9 @@ async def test_search_all_resources_flattened_async():
 
 @pytest.mark.asyncio
 async def test_search_all_resources_flattened_error_async():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -855,7 +902,8 @@ async def test_search_all_resources_flattened_error_async():
 
 def test_search_all_resources_pager(transport_name: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -873,10 +921,14 @@ def test_search_all_resources_pager(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[assets.StandardResourceMetadata(),], next_page_token="ghi",
+                results=[
+                    assets.StandardResourceMetadata(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllResourcesResponse(
                 results=[
@@ -895,14 +947,15 @@ def test_search_all_resources_pager(transport_name: str = "grpc"):
 
         assert pager._metadata == metadata
 
-        results = [i for i in pager]
+        results = list(pager)
         assert len(results) == 6
         assert all(isinstance(i, assets.StandardResourceMetadata) for i in results)
 
 
 def test_search_all_resources_pages(transport_name: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -920,10 +973,14 @@ def test_search_all_resources_pages(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[assets.StandardResourceMetadata(),], next_page_token="ghi",
+                results=[
+                    assets.StandardResourceMetadata(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllResourcesResponse(
                 results=[
@@ -940,7 +997,9 @@ def test_search_all_resources_pages(transport_name: str = "grpc"):
 
 @pytest.mark.asyncio
 async def test_search_all_resources_async_pager():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -959,10 +1018,14 @@ async def test_search_all_resources_async_pager():
                 next_page_token="abc",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[assets.StandardResourceMetadata(),], next_page_token="ghi",
+                results=[
+                    assets.StandardResourceMetadata(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllResourcesResponse(
                 results=[
@@ -972,10 +1035,12 @@ async def test_search_all_resources_async_pager():
             ),
             RuntimeError,
         )
-        async_pager = await client.search_all_resources(request={},)
+        async_pager = await client.search_all_resources(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
-        async for response in async_pager:
+        async for response in async_pager:  # pragma: no branch
             responses.append(response)
 
         assert len(responses) == 6
@@ -984,7 +1049,9 @@ async def test_search_all_resources_async_pager():
 
 @pytest.mark.asyncio
 async def test_search_all_resources_async_pages():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1003,10 +1070,14 @@ async def test_search_all_resources_async_pages():
                 next_page_token="abc",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllResourcesResponse(
-                results=[assets.StandardResourceMetadata(),], next_page_token="ghi",
+                results=[
+                    assets.StandardResourceMetadata(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllResourcesResponse(
                 results=[
@@ -1017,18 +1088,25 @@ async def test_search_all_resources_async_pages():
             RuntimeError,
         )
         pages = []
-        async for page_ in (await client.search_all_resources(request={})).pages:
+        async for page_ in (
+            await client.search_all_resources(request={})
+        ).pages:  # pragma: no branch
             pages.append(page_)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
 
 
 @pytest.mark.parametrize(
-    "request_type", [asset_service.SearchAllIamPoliciesRequest, dict,]
+    "request_type",
+    [
+        asset_service.SearchAllIamPoliciesRequest,
+        dict,
+    ],
 )
 def test_search_all_iam_policies(request_type, transport: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1059,7 +1137,8 @@ def test_search_all_iam_policies_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1078,7 +1157,8 @@ async def test_search_all_iam_policies_async(
     request_type=asset_service.SearchAllIamPoliciesRequest,
 ):
     client = AssetServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1113,13 +1193,15 @@ async def test_search_all_iam_policies_async_from_dict():
 
 
 def test_search_all_iam_policies_field_headers():
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = asset_service.SearchAllIamPoliciesRequest()
 
-    request.scope = "scope/value"
+    request.scope = "scope_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1135,18 +1217,23 @@ def test_search_all_iam_policies_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "scope=scope/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "scope=scope_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
 async def test_search_all_iam_policies_field_headers_async():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = asset_service.SearchAllIamPoliciesRequest()
 
-    request.scope = "scope/value"
+    request.scope = "scope_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1164,11 +1251,16 @@ async def test_search_all_iam_policies_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "scope=scope/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "scope=scope_value",
+    ) in kw["metadata"]
 
 
 def test_search_all_iam_policies_flattened():
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1179,7 +1271,8 @@ def test_search_all_iam_policies_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.search_all_iam_policies(
-            scope="scope_value", query="query_value",
+            scope="scope_value",
+            query="query_value",
         )
 
         # Establish that the underlying call was made with the expected
@@ -1195,7 +1288,9 @@ def test_search_all_iam_policies_flattened():
 
 
 def test_search_all_iam_policies_flattened_error():
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1209,7 +1304,9 @@ def test_search_all_iam_policies_flattened_error():
 
 @pytest.mark.asyncio
 async def test_search_all_iam_policies_flattened_async():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1224,7 +1321,8 @@ async def test_search_all_iam_policies_flattened_async():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         response = await client.search_all_iam_policies(
-            scope="scope_value", query="query_value",
+            scope="scope_value",
+            query="query_value",
         )
 
         # Establish that the underlying call was made with the expected
@@ -1241,7 +1339,9 @@ async def test_search_all_iam_policies_flattened_async():
 
 @pytest.mark.asyncio
 async def test_search_all_iam_policies_flattened_error_async():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1255,7 +1355,8 @@ async def test_search_all_iam_policies_flattened_error_async():
 
 def test_search_all_iam_policies_pager(transport_name: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1273,10 +1374,14 @@ def test_search_all_iam_policies_pager(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[assets.IamPolicySearchResult(),], next_page_token="ghi",
+                results=[
+                    assets.IamPolicySearchResult(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllIamPoliciesResponse(
                 results=[
@@ -1295,14 +1400,15 @@ def test_search_all_iam_policies_pager(transport_name: str = "grpc"):
 
         assert pager._metadata == metadata
 
-        results = [i for i in pager]
+        results = list(pager)
         assert len(results) == 6
         assert all(isinstance(i, assets.IamPolicySearchResult) for i in results)
 
 
 def test_search_all_iam_policies_pages(transport_name: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1320,10 +1426,14 @@ def test_search_all_iam_policies_pages(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[assets.IamPolicySearchResult(),], next_page_token="ghi",
+                results=[
+                    assets.IamPolicySearchResult(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllIamPoliciesResponse(
                 results=[
@@ -1340,7 +1450,9 @@ def test_search_all_iam_policies_pages(transport_name: str = "grpc"):
 
 @pytest.mark.asyncio
 async def test_search_all_iam_policies_async_pager():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1359,10 +1471,14 @@ async def test_search_all_iam_policies_async_pager():
                 next_page_token="abc",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[assets.IamPolicySearchResult(),], next_page_token="ghi",
+                results=[
+                    assets.IamPolicySearchResult(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllIamPoliciesResponse(
                 results=[
@@ -1372,10 +1488,12 @@ async def test_search_all_iam_policies_async_pager():
             ),
             RuntimeError,
         )
-        async_pager = await client.search_all_iam_policies(request={},)
+        async_pager = await client.search_all_iam_policies(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
-        async for response in async_pager:
+        async for response in async_pager:  # pragma: no branch
             responses.append(response)
 
         assert len(responses) == 6
@@ -1384,7 +1502,9 @@ async def test_search_all_iam_policies_async_pager():
 
 @pytest.mark.asyncio
 async def test_search_all_iam_policies_async_pages():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1403,10 +1523,14 @@ async def test_search_all_iam_policies_async_pages():
                 next_page_token="abc",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[], next_page_token="def",
+                results=[],
+                next_page_token="def",
             ),
             asset_service.SearchAllIamPoliciesResponse(
-                results=[assets.IamPolicySearchResult(),], next_page_token="ghi",
+                results=[
+                    assets.IamPolicySearchResult(),
+                ],
+                next_page_token="ghi",
             ),
             asset_service.SearchAllIamPoliciesResponse(
                 results=[
@@ -1417,7 +1541,9 @@ async def test_search_all_iam_policies_async_pages():
             RuntimeError,
         )
         pages = []
-        async for page_ in (await client.search_all_iam_policies(request={})).pages:
+        async for page_ in (
+            await client.search_all_iam_policies(request={})
+        ).pages:  # pragma: no branch
             pages.append(page_)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
@@ -1430,7 +1556,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AssetServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1450,7 +1577,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = AssetServiceClient(client_options=options, transport=transport,)
+        client = AssetServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1466,7 +1596,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AssetServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1509,10 +1640,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = AssetServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.AssetServiceGrpcTransport,)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.AssetServiceGrpcTransport,
+    )
 
 
 def test_asset_service_base_transport_error():
@@ -1547,6 +1696,14 @@ def test_asset_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_asset_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1558,7 +1715,8 @@ def test_asset_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.AssetServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1688,24 +1846,40 @@ def test_asset_service_grpc_transport_client_cert_source_for_mtls(transport_clas
             )
 
 
-def test_asset_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_asset_service_host_no_port(transport_name):
     client = AssetServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="cloudasset.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "cloudasset.googleapis.com:443"
+    assert client.transport._host == ("cloudasset.googleapis.com:443")
 
 
-def test_asset_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_asset_service_host_with_port(transport_name):
     client = AssetServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="cloudasset.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "cloudasset.googleapis.com:8000"
+    assert client.transport._host == ("cloudasset.googleapis.com:8000")
 
 
 def test_asset_service_grpc_transport_channel():
@@ -1713,7 +1887,8 @@ def test_asset_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AssetServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1725,7 +1900,8 @@ def test_asset_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AssetServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1846,7 +2022,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = AssetServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1864,7 +2042,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = AssetServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1882,7 +2062,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = AssetServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1902,7 +2084,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = AssetServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1927,7 +2110,8 @@ def test_client_with_default_client_info():
         transports.AssetServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = AssetServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1936,7 +2120,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = AssetServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1944,7 +2129,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = AssetServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
