@@ -87,19 +87,25 @@ def test__get_default_mtls_endpoint():
     assert AssetServiceClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-@pytest.mark.parametrize("client_class", [AssetServiceClient, AssetServiceAsyncClient,])
-def test_asset_service_client_from_service_account_info(client_class):
+@pytest.mark.parametrize(
+    "client_class,transport_name",
+    [
+        (AssetServiceClient, "grpc"),
+        (AssetServiceAsyncClient, "grpc_asyncio"),
+    ],
+)
+def test_asset_service_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "cloudasset.googleapis.com:443"
+        assert client.transport._host == ("cloudasset.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -127,22 +133,32 @@ def test_asset_service_client_service_account_always_use_jwt(
         use_jwt.assert_not_called()
 
 
-@pytest.mark.parametrize("client_class", [AssetServiceClient, AssetServiceAsyncClient,])
-def test_asset_service_client_from_service_account_file(client_class):
+@pytest.mark.parametrize(
+    "client_class,transport_name",
+    [
+        (AssetServiceClient, "grpc"),
+        (AssetServiceAsyncClient, "grpc_asyncio"),
+    ],
+)
+def test_asset_service_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "cloudasset.googleapis.com:443"
+        assert client.transport._host == ("cloudasset.googleapis.com:443")
 
 
 def test_asset_service_client_get_transport_class():
@@ -482,7 +498,9 @@ def test_asset_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -620,10 +638,17 @@ def test_asset_service_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [asset_service.AnalyzeIamPolicyRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        asset_service.AnalyzeIamPolicyRequest,
+        dict,
+    ],
+)
 def test_analyze_iam_policy(request_type, transport: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -635,7 +660,9 @@ def test_analyze_iam_policy(request_type, transport: str = "grpc"):
         type(client.transport.analyze_iam_policy), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
-        call.return_value = asset_service.AnalyzeIamPolicyResponse(fully_explored=True,)
+        call.return_value = asset_service.AnalyzeIamPolicyResponse(
+            fully_explored=True,
+        )
         response = client.analyze_iam_policy(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -652,7 +679,8 @@ def test_analyze_iam_policy_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -670,7 +698,8 @@ async def test_analyze_iam_policy_async(
     transport: str = "grpc_asyncio", request_type=asset_service.AnalyzeIamPolicyRequest
 ):
     client = AssetServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -683,7 +712,9 @@ async def test_analyze_iam_policy_async(
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            asset_service.AnalyzeIamPolicyResponse(fully_explored=True,)
+            asset_service.AnalyzeIamPolicyResponse(
+                fully_explored=True,
+            )
         )
         response = await client.analyze_iam_policy(request)
 
@@ -703,13 +734,15 @@ async def test_analyze_iam_policy_async_from_dict():
 
 
 def test_analyze_iam_policy_field_headers():
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = asset_service.AnalyzeIamPolicyRequest()
 
-    request.analysis_query.parent = "analysis_query.parent/value"
+    request.analysis_query.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -727,19 +760,21 @@ def test_analyze_iam_policy_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "analysis_query.parent=analysis_query.parent/value",
+        "analysis_query.parent=parent_value",
     ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
 async def test_analyze_iam_policy_field_headers_async():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = asset_service.AnalyzeIamPolicyRequest()
 
-    request.analysis_query.parent = "analysis_query.parent/value"
+    request.analysis_query.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -759,16 +794,21 @@ async def test_analyze_iam_policy_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "analysis_query.parent=analysis_query.parent/value",
+        "analysis_query.parent=parent_value",
     ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [asset_service.ExportIamPolicyAnalysisRequest, dict,]
+    "request_type",
+    [
+        asset_service.ExportIamPolicyAnalysisRequest,
+        dict,
+    ],
 )
 def test_export_iam_policy_analysis(request_type, transport: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -796,7 +836,8 @@ def test_export_iam_policy_analysis_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -815,7 +856,8 @@ async def test_export_iam_policy_analysis_async(
     request_type=asset_service.ExportIamPolicyAnalysisRequest,
 ):
     client = AssetServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -847,13 +889,15 @@ async def test_export_iam_policy_analysis_async_from_dict():
 
 
 def test_export_iam_policy_analysis_field_headers():
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = asset_service.ExportIamPolicyAnalysisRequest()
 
-    request.analysis_query.parent = "analysis_query.parent/value"
+    request.analysis_query.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -871,19 +915,21 @@ def test_export_iam_policy_analysis_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "analysis_query.parent=analysis_query.parent/value",
+        "analysis_query.parent=parent_value",
     ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
 async def test_export_iam_policy_analysis_field_headers_async():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = asset_service.ExportIamPolicyAnalysisRequest()
 
-    request.analysis_query.parent = "analysis_query.parent/value"
+    request.analysis_query.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -903,7 +949,7 @@ async def test_export_iam_policy_analysis_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "analysis_query.parent=analysis_query.parent/value",
+        "analysis_query.parent=parent_value",
     ) in kw["metadata"]
 
 
@@ -914,7 +960,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AssetServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -934,7 +981,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = AssetServiceClient(client_options=options, transport=transport,)
+        client = AssetServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -950,7 +1000,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AssetServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -993,10 +1044,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = AssetServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.AssetServiceGrpcTransport,)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.AssetServiceGrpcTransport,
+    )
 
 
 def test_asset_service_base_transport_error():
@@ -1036,6 +1105,14 @@ def test_asset_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.operations_client
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_asset_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1047,7 +1124,8 @@ def test_asset_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.AssetServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1177,24 +1255,40 @@ def test_asset_service_grpc_transport_client_cert_source_for_mtls(transport_clas
             )
 
 
-def test_asset_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_asset_service_host_no_port(transport_name):
     client = AssetServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="cloudasset.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "cloudasset.googleapis.com:443"
+    assert client.transport._host == ("cloudasset.googleapis.com:443")
 
 
-def test_asset_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_asset_service_host_with_port(transport_name):
     client = AssetServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="cloudasset.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "cloudasset.googleapis.com:8000"
+    assert client.transport._host == ("cloudasset.googleapis.com:8000")
 
 
 def test_asset_service_grpc_transport_channel():
@@ -1202,7 +1296,8 @@ def test_asset_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AssetServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1214,7 +1309,8 @@ def test_asset_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AssetServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1315,12 +1411,16 @@ def test_asset_service_transport_channel_mtls_with_adc(transport_class):
 
 def test_asset_service_grpc_lro_client():
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1328,12 +1428,16 @@ def test_asset_service_grpc_lro_client():
 
 def test_asset_service_grpc_lro_async_client():
     client = AssetServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsAsyncClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1361,7 +1465,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = AssetServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1379,7 +1485,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = AssetServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1397,7 +1505,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = AssetServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1417,7 +1527,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = AssetServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1442,7 +1553,8 @@ def test_client_with_default_client_info():
         transports.AssetServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = AssetServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1451,7 +1563,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = AssetServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1459,7 +1572,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = AssetServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
