@@ -83,19 +83,25 @@ def test__get_default_mtls_endpoint():
     assert AssetServiceClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-@pytest.mark.parametrize("client_class", [AssetServiceClient, AssetServiceAsyncClient,])
-def test_asset_service_client_from_service_account_info(client_class):
+@pytest.mark.parametrize(
+    "client_class,transport_name",
+    [
+        (AssetServiceClient, "grpc"),
+        (AssetServiceAsyncClient, "grpc_asyncio"),
+    ],
+)
+def test_asset_service_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "cloudasset.googleapis.com:443"
+        assert client.transport._host == ("cloudasset.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -123,22 +129,32 @@ def test_asset_service_client_service_account_always_use_jwt(
         use_jwt.assert_not_called()
 
 
-@pytest.mark.parametrize("client_class", [AssetServiceClient, AssetServiceAsyncClient,])
-def test_asset_service_client_from_service_account_file(client_class):
+@pytest.mark.parametrize(
+    "client_class,transport_name",
+    [
+        (AssetServiceClient, "grpc"),
+        (AssetServiceAsyncClient, "grpc_asyncio"),
+    ],
+)
+def test_asset_service_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "cloudasset.googleapis.com:443"
+        assert client.transport._host == ("cloudasset.googleapis.com:443")
 
 
 def test_asset_service_client_get_transport_class():
@@ -478,7 +494,9 @@ def test_asset_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -616,10 +634,17 @@ def test_asset_service_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [asset_service.ListAssetsRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        asset_service.ListAssetsRequest,
+        dict,
+    ],
+)
 def test_list_assets(request_type, transport: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -648,7 +673,8 @@ def test_list_assets_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -664,7 +690,8 @@ async def test_list_assets_async(
     transport: str = "grpc_asyncio", request_type=asset_service.ListAssetsRequest
 ):
     client = AssetServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -675,7 +702,9 @@ async def test_list_assets_async(
     with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            asset_service.ListAssetsResponse(next_page_token="next_page_token_value",)
+            asset_service.ListAssetsResponse(
+                next_page_token="next_page_token_value",
+            )
         )
         response = await client.list_assets(request)
 
@@ -695,13 +724,15 @@ async def test_list_assets_async_from_dict():
 
 
 def test_list_assets_field_headers():
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = asset_service.ListAssetsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
@@ -715,18 +746,23 @@ def test_list_assets_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
 async def test_list_assets_field_headers_async():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = asset_service.ListAssetsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_assets), "__call__") as call:
@@ -742,12 +778,16 @@ async def test_list_assets_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 def test_list_assets_pager(transport_name: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -755,14 +795,29 @@ def test_list_assets_pager(transport_name: str = "grpc"):
         # Set the response to a series of pages.
         call.side_effect = (
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(), assets.Asset(), assets.Asset(),],
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
                 next_page_token="abc",
             ),
-            asset_service.ListAssetsResponse(assets=[], next_page_token="def",),
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(),], next_page_token="ghi",
+                assets=[],
+                next_page_token="def",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                ],
+                next_page_token="ghi",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
             ),
-            asset_service.ListAssetsResponse(assets=[assets.Asset(), assets.Asset(),],),
             RuntimeError,
         )
 
@@ -774,14 +829,15 @@ def test_list_assets_pager(transport_name: str = "grpc"):
 
         assert pager._metadata == metadata
 
-        results = [i for i in pager]
+        results = list(pager)
         assert len(results) == 6
         assert all(isinstance(i, assets.Asset) for i in results)
 
 
 def test_list_assets_pages(transport_name: str = "grpc"):
     client = AssetServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -789,14 +845,29 @@ def test_list_assets_pages(transport_name: str = "grpc"):
         # Set the response to a series of pages.
         call.side_effect = (
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(), assets.Asset(), assets.Asset(),],
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
                 next_page_token="abc",
             ),
-            asset_service.ListAssetsResponse(assets=[], next_page_token="def",),
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(),], next_page_token="ghi",
+                assets=[],
+                next_page_token="def",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                ],
+                next_page_token="ghi",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
             ),
-            asset_service.ListAssetsResponse(assets=[assets.Asset(), assets.Asset(),],),
             RuntimeError,
         )
         pages = list(client.list_assets(request={}).pages)
@@ -806,7 +877,9 @@ def test_list_assets_pages(transport_name: str = "grpc"):
 
 @pytest.mark.asyncio
 async def test_list_assets_async_pager():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -815,20 +888,37 @@ async def test_list_assets_async_pager():
         # Set the response to a series of pages.
         call.side_effect = (
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(), assets.Asset(), assets.Asset(),],
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
                 next_page_token="abc",
             ),
-            asset_service.ListAssetsResponse(assets=[], next_page_token="def",),
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(),], next_page_token="ghi",
+                assets=[],
+                next_page_token="def",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                ],
+                next_page_token="ghi",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
             ),
-            asset_service.ListAssetsResponse(assets=[assets.Asset(), assets.Asset(),],),
             RuntimeError,
         )
-        async_pager = await client.list_assets(request={},)
+        async_pager = await client.list_assets(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
-        async for response in async_pager:
+        async for response in async_pager:  # pragma: no branch
             responses.append(response)
 
         assert len(responses) == 6
@@ -837,7 +927,9 @@ async def test_list_assets_async_pager():
 
 @pytest.mark.asyncio
 async def test_list_assets_async_pages():
-    client = AssetServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = AssetServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -846,18 +938,35 @@ async def test_list_assets_async_pages():
         # Set the response to a series of pages.
         call.side_effect = (
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(), assets.Asset(), assets.Asset(),],
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
                 next_page_token="abc",
             ),
-            asset_service.ListAssetsResponse(assets=[], next_page_token="def",),
             asset_service.ListAssetsResponse(
-                assets=[assets.Asset(),], next_page_token="ghi",
+                assets=[],
+                next_page_token="def",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                ],
+                next_page_token="ghi",
+            ),
+            asset_service.ListAssetsResponse(
+                assets=[
+                    assets.Asset(),
+                    assets.Asset(),
+                ],
             ),
-            asset_service.ListAssetsResponse(assets=[assets.Asset(), assets.Asset(),],),
             RuntimeError,
         )
         pages = []
-        async for page_ in (await client.list_assets(request={})).pages:
+        async for page_ in (
+            await client.list_assets(request={})
+        ).pages:  # pragma: no branch
             pages.append(page_)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
@@ -870,7 +979,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AssetServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -890,7 +1000,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = AssetServiceClient(client_options=options, transport=transport,)
+        client = AssetServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -906,7 +1019,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = AssetServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -949,10 +1063,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = AssetServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = AssetServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.AssetServiceGrpcTransport,)
+    client = AssetServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.AssetServiceGrpcTransport,
+    )
 
 
 def test_asset_service_base_transport_error():
@@ -984,6 +1116,14 @@ def test_asset_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_asset_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -995,7 +1135,8 @@ def test_asset_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.AssetServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1125,24 +1266,40 @@ def test_asset_service_grpc_transport_client_cert_source_for_mtls(transport_clas
             )
 
 
-def test_asset_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_asset_service_host_no_port(transport_name):
     client = AssetServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="cloudasset.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "cloudasset.googleapis.com:443"
+    assert client.transport._host == ("cloudasset.googleapis.com:443")
 
 
-def test_asset_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_asset_service_host_with_port(transport_name):
     client = AssetServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="cloudasset.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "cloudasset.googleapis.com:8000"
+    assert client.transport._host == ("cloudasset.googleapis.com:8000")
 
 
 def test_asset_service_grpc_transport_channel():
@@ -1150,7 +1307,8 @@ def test_asset_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AssetServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1162,7 +1320,8 @@ def test_asset_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.AssetServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1265,7 +1424,8 @@ def test_access_level_path():
     access_policy = "squid"
     access_level = "clam"
     expected = "accessPolicies/{access_policy}/accessLevels/{access_level}".format(
-        access_policy=access_policy, access_level=access_level,
+        access_policy=access_policy,
+        access_level=access_level,
     )
     actual = AssetServiceClient.access_level_path(access_policy, access_level)
     assert expected == actual
@@ -1285,7 +1445,9 @@ def test_parse_access_level_path():
 
 def test_access_policy_path():
     access_policy = "oyster"
-    expected = "accessPolicies/{access_policy}".format(access_policy=access_policy,)
+    expected = "accessPolicies/{access_policy}".format(
+        access_policy=access_policy,
+    )
     actual = AssetServiceClient.access_policy_path(access_policy)
     assert expected == actual
 
@@ -1310,8 +1472,11 @@ def test_asset_path():
 def test_service_perimeter_path():
     access_policy = "cuttlefish"
     service_perimeter = "mussel"
-    expected = "accessPolicies/{access_policy}/servicePerimeters/{service_perimeter}".format(
-        access_policy=access_policy, service_perimeter=service_perimeter,
+    expected = (
+        "accessPolicies/{access_policy}/servicePerimeters/{service_perimeter}".format(
+            access_policy=access_policy,
+            service_perimeter=service_perimeter,
+        )
     )
     actual = AssetServiceClient.service_perimeter_path(access_policy, service_perimeter)
     assert expected == actual
@@ -1351,7 +1516,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "squid"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = AssetServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1369,7 +1536,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "whelk"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = AssetServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1387,7 +1556,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "oyster"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = AssetServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1407,7 +1578,8 @@ def test_common_location_path():
     project = "cuttlefish"
     location = "mussel"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = AssetServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1432,7 +1604,8 @@ def test_client_with_default_client_info():
         transports.AssetServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = AssetServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1441,7 +1614,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = AssetServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1449,7 +1623,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = AssetServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
